@@ -1,19 +1,13 @@
-/*************************************************************************
- *  Copyright (C) 2008 by Volker Lanz <vl@fidra.de>                      *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2008 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2020 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2015 Chris Campbell <c.j.campbell@ed.ac.uk>
+    SPDX-FileCopyrightText: 2015 Teo Mrnjavac <teo@kde.org>
+    SPDX-FileCopyrightText: 2020 Gaël PORTAY <gael.portay@collabora.com>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #ifndef KPMCORE_PARTITION_H
 #define KPMCORE_PARTITION_H
@@ -24,7 +18,6 @@
 
 #include "util/libpartitionmanagerexport.h"
 
-#include <QStringList>
 #include <QtGlobal>
 #include <QPointer>
 
@@ -80,13 +73,9 @@ public:
         New,       /**< from a NewOperation */
         Copy,      /**< from a CopyOperation */
         Restore,   /**< from a RestoreOperation */
-        StateNone [[deprecated("Use Partition::State::None")]] = None,
-        StateNew [[deprecated("Use Partition::State::New")]] = New,
-        StateCopy [[deprecated("Use Partition::State::Copy")]] = Copy,
-        StateRestore [[deprecated("Use Partition::State::Restore")]] = Restore
     };
 
-    Partition(PartitionNode* parent, const Device& device, const PartitionRole& role, FileSystem* fs, qint64 sectorStart, qint64 sectorEnd, QString partitionPath, PartitionTable::Flags availableFlags = PartitionTable::FlagNone, const QString& mountPoint = QString(), bool mounted = false, PartitionTable::Flags activeFlags = PartitionTable::FlagNone, State state = State::None);
+    Partition(PartitionNode* parent, const Device& device, const PartitionRole& role, FileSystem* fs, qint64 sectorStart, qint64 sectorEnd, QString partitionPath, PartitionTable::Flags availableFlags = PartitionTable::Flag::None, const QString& mountPoint = QString(), bool mounted = false, PartitionTable::Flags activeFlags = PartitionTable::Flag::None, State state = State::None);
     ~Partition() override;
 
     Partition(const Partition& other, PartitionNode* parent = nullptr);
@@ -103,6 +92,8 @@ public:
         return false;    /**< @return always false for Partition */
     }
 
+    const PartitionTable* partitionTable() const;
+
     PartitionNode* parent() override {
         return m_Parent;    /**< @return the Partition's parent PartitionNode */
     }
@@ -125,9 +116,15 @@ public:
     const QString& label() const {
         return m_Label;    /**< @return the GPT Partition label */
     }
+    const QString& type() const {
+        return m_Type;    /**< @return the GPT Partition type */
+    }
     const QString& uuid() const {
         return m_UUID;    /**< @return the GPT Partition UUID */
     }
+    quint64 attributes() const {
+        return m_Attributes;    /**< @return the GPT Partition attributes */
+    }
     qint64 firstSector() const {
         return m_FirstSector;    /**< @return the Partition's first sector on the Device */
     }
@@ -180,6 +177,9 @@ public:
     bool isMounted() const {
         return m_IsMounted;    /**< @return true if Partition is mounted */
     }
+    bool isFileSystemNullptr() {
+        return m_FileSystem == nullptr;
+    }
     FileSystem& fileSystem() {
         return *m_FileSystem;    /**< @return the Partition's FileSystem */
     }
@@ -210,9 +210,15 @@ public:
     void setLabel(const QString& s) {
         m_Label = s;    /**< @param s the new label */
     }
+    void setType(const QString& s) {
+        m_Type = s;    /**< @param s the new type */
+    }
     void setUUID(const QString& s) {
         m_UUID = s;    /**< @param s the new UUID */
     }
+    void setAttributes(quint64 f) {
+        m_Attributes = f;    /**< @param f the new attributes */
+    }
 
     void append(Partition* p) override {
         m_Children.append(p);
@@ -238,10 +244,10 @@ public:
     void setMounted(bool b);
 
     void setFlag(PartitionTable::Flag f) {
-        m_ActiveFlags |= f;
+        m_ActiveFlags = m_ActiveFlags.setFlag(f);
     }
     void unsetFlag(PartitionTable::Flag f) {
-        m_ActiveFlags &= ~f;
+        m_ActiveFlags = m_ActiveFlags.setFlag(f, false);
     }
     void setParent(PartitionNode* p) {
         m_Parent = p;
@@ -257,23 +263,25 @@ private:
         m_Number = n;
     }
 
-    qint32 m_Number;
+    qint32 m_Number = 0;
     Partitions m_Children;
-    QPointer< PartitionNode > m_Parent;
-    FileSystem* m_FileSystem;
+    QPointer< PartitionNode > m_Parent = nullptr;
+    FileSystem* m_FileSystem = nullptr;
     PartitionRole m_Roles;
-    qint64 m_FirstSector;
-    qint64 m_LastSector;
+    qint64 m_FirstSector = 0;
+    qint64 m_LastSector = 0;
     QString m_DevicePath;
     QString m_Label;
+    QString m_Type;
     QString m_UUID;
+    quint64 m_Attributes = 0;
     QString m_PartitionPath;
     QString m_MountPoint;
     PartitionTable::Flags m_AvailableFlags;
     PartitionTable::Flags m_ActiveFlags;
-    bool m_IsMounted;
-    qint64 m_SectorSize;
-    State m_State;
+    bool m_IsMounted = false;
+    qint64 m_SectorSize = 0;
+    State m_State = None;
 };
 
 QTextStream& operator<<(QTextStream& stream, const Partition& p);
